@@ -18,6 +18,7 @@ namespace eval ::annotate {
       variable w .annotate$my_idx
 
       global cvs
+      global tcl_platform
 
       proc redo {w} {
         global cvscfg
@@ -149,7 +150,9 @@ namespace eval ::annotate {
       if {$revision != ""} {
         wm title $w "$file Revision $revlabel"
       }
-      wm iconbitmap $w @$cvscfg(bitmapdir)/annotate.xbm
+      if {$tcl_platform(platform) != "windows"} {
+        wm iconbitmap $w @$cvscfg(bitmapdir)/annotate.xbm
+      }
 
       # Define the colors
       array set agecolors {
