@@ -3,7 +3,7 @@
 #
 
 #
-# $Id: cvs.tcl,v 1.124 2004/01/02 07:11:12 dorothyr Exp $
+# $Id: cvs.tcl,v 1.127 2004/03/18 06:36:29 dorothyr Exp $
 # 
 # Contains procedures used in interaction with CVS.
 #
@@ -163,7 +163,7 @@ proc cvs_remove_dir {args} {
 
       set commandline "$cvs remove \"$file\""
       #gen_log:log C "$commandline"
-      $v\::do "$commandline" status_colortags
+      $v\::do "$commandline" 1 status_colortags
       $v\::wait
     }
   }
@@ -827,7 +827,8 @@ proc cvs_commit {revision comment args} {
     }
     set v [viewer::new "CVS Commit"]
     regsub -all "\"" $comment "\\\"" comment
-    $v\::do "$cvs commit -R $revflag -m \"$comment\" $filelist"
+    # Lets not show stderr as it does a lot of "examining"
+    $v\::do "$cvs commit -R $revflag -m \"$comment\" $filelist" 0
     $v\::wait
   }
 
@@ -877,7 +878,7 @@ proc cvs_tag {tagname force branch args} {
     # update so we're on the branch
     set command "$cvs update -r $tagname $filelist"
     #gen_log:log C "$command"
-    $v\::do "$command" status_colortags
+    $v\::do "$command" 0 status_colortags
     $v\::wait
   }
 
@@ -974,7 +975,7 @@ proc cvs_update {tagname normal_binary action_if_no_tag get_all_dirs dir args} {
 
     #gen_log:log C $commandline
     set check_cmd [viewer::new "CVS Update"]
-    $check_cmd\::do $commandline status_colortags
+    $check_cmd\::do $commandline 0 status_colortags
     
     if {$cvscfg(auto_status)} {
       $check_cmd\::wait
@@ -999,7 +1000,13 @@ proc cvs_join {from since fromtag totag args} {
   set v [viewer::new "CVS Join"]
 
   set commandline "$cvs update -d -j$from $filelist"
-  $v\::do "$cvs update -d -j$from $filelist" status_colortags
+  if {$since == ""} {
+    set commandline "$cvs update -d -j$from $filelist"
+  } else {
+    set commandline "$cvs update -d -j$since -j$from $filelist"
+  }
+    
+  $v\::do "$commandline" 0 status_colortags
   $v\::wait
 
   if {$cvscfg(auto_tag)} {
@@ -1029,51 +1036,6 @@ proc cvs_join {from since fromtag totag args} {
   gen_log:log T "LEAVE"
 }
 
-proc cvs_delta {ver1 ver2 args} {
-#
-# This merges the changes between ver1 and ver2 into the current revision.
-#
-  global cvs
-  global cvscfg
-  global incvs
-
-  gen_log:log T "ENTER (\"$ver1\" \"$ver2\" \"$args\")"
-  if {! $incvs} {
-    cvs_notincvs
-    return 1
-  }
-
-  if {$ver1 == "" || $ver2 == ""} {
-    cvsfail "Must have two revision numbers for this function!"
-    return 1
-  }
-
-  set filelist [join $args]
-
-  set mess "This will merge the changes between revision $ver1 and $ver2"
-  append mess " (if $ver1 > $ver2 the changes are removed)"
-  if {$filelist == ""} {
-    append mess " to the current revision of all files"
-  } else {
-    append mess " to the current revision of these files:"
-    foreach file $filelist {
-      append mess "\n\t$file"
-    }
-  }
-  append mess "\n\nAre you sure?"
-  if {[cvsconfirm $mess] == 0} {
-    set commandline "$cvs update -d -j$ver1 -j$ver2 $filelist"
-    #gen_log:log C "$commandline"
-    set v [viewer::new "CVS Merge"]
-    $v\::do "$commandline" status_colortags
-    if {$cvscfg(auto_status)} {
-      $v\::wait
-      setup_dir
-    }
-  }
-  gen_log:log T "LEAVE"
-}
-
 proc cvs_status {args} {
 #
 # This does a status report on the files in the current directory.
@@ -1134,7 +1096,7 @@ proc cvs_status {args} {
     view_output::new "CVS Status ($cvscfg(rdetail))" $cooked_status
   }
 
-  # reset the verbosity setting if necessary -jo
+  # reset the verbosity setting if necessary
   if { $verbosity_setting != "" } {
     set cvscfg(rdetail) $verbosity_setting
   }
@@ -1205,7 +1167,7 @@ proc cvs_check {directory} {
   set commandline "$cvs -n -q update $cvscfg(checkrecursive) $directory"
   #gen_log:log C "$commandline"
   set check_cmd [viewer::new "Directory Status Check"]
-  $check_cmd\::do $commandline status_colortags
+  $check_cmd\::do $commandline 0 status_colortags
 
   busy_done .workdir.main
   gen_log:log T "LEAVE"
@@ -1382,7 +1344,7 @@ proc cvs_patch { cvsroot module difffmt revtagA dateA revtagB dateB outmode outf
 
   if {$outmode == 0} {
     set v [viewer::new "CVS Patch"]
-    $v\::do "$commandline" patch_colortags
+    $v\::do "$commandline" 0 patch_colortags
   } else {
     set e [exec::new "$commandline"]
     set patch [$e\::output]
@@ -1424,7 +1386,7 @@ proc cvs_version_number {} {
   gen_log:log T "ENTER"
   set commandline "$cvs -v"
   #gen_log:log C "$commandline"
-  set e [exec::new "$commandline" {} parse_version]
+  set e [exec::new "$commandline" {} 0 parse_version]
   set number [$e\::output]
   regsub -all {\s*} $number {} number
   
