@@ -3,7 +3,7 @@
 #
 
 #
-# $Id: dialog.tcl,v 1.32 2004/01/02 07:11:13 dorothyr Exp $
+# $Id: dialog.tcl,v 1.34 2004/04/20 04:50:45 dorothyr Exp $
 #
 # Smallish dialogs - add, tag
 #
@@ -574,14 +574,16 @@ proc merge_dialog { from since file {fromtag {}} } {
     checkbutton .merge.top.f.fromtag \
       -text "Apply the tag" \
       -variable cvscfg(auto_tag)
-    entry .merge.top.f.ent -width 32 -relief raised -bd 1
+    entry .merge.top.f.ent -textvariable mtag \
+      -width 32 -relief raised -bd 1 
+    .merge.top.f.ent delete 0 end
     .merge.top.f.ent insert end $mtag
     message .merge.top.m2 -aspect 600 -text "to revision $from"
     frame .merge.bottom -relief raised -bd 2
     button .merge.bottom.apply -text "Apply" \
-      -command "cvs_join $from $since $mtag $ftag $file"
+      -command "cvs_join $from $since \[.merge.top.f.ent get\] $ftag $file"
     button .merge.bottom.ok -text "OK" \
-      -command "cvs_join $from $since $mtag $ftag $file; destroy .merge"
+      -command "cvs_join $from $since \[.merge.top.f.ent get\] $ftag $file; destroy .merge"
     button .merge.bottom.cancel -text "Cancel" \
       -command "destroy .merge"
 
