@@ -41,16 +41,19 @@ proc cvs_catchcmd {args} {
 namespace eval ::exec {
   variable instance 0
 
-  proc new {command {viewer {}} {filter {}}} {
+  proc new {command {viewer {}} {show_stderr {1}} {filter {}}} {
     variable instance
     set my_idx $instance
     incr instance
 
+    gen_log:log T "ENTER (\"$command\" \"$show_stderr\" \"$filter\")"
+
     namespace eval $my_idx {
       set my_idx [uplevel {concat $my_idx}]
       variable command [uplevel {concat $command}]
       variable viewer [uplevel {concat $viewer}]
       variable filter [uplevel {concat $filter}]
+      variable show_stderr [uplevel {concat $show_stderr}]
 
       global cvscfg
       global errorCode
@@ -69,6 +72,7 @@ namespace eval ::exec {
 
       proc out_handler {{viewer {}} {filter {}}} {
         variable procout
+        variable procerr
         variable ExecDone
         variable errmsg
         variable data
@@ -84,6 +88,17 @@ namespace eval ::exec {
             set ExecDone [list 1 $res $errorCode]
             gen_log:log E "  ExecDone $ExecDone"
             if {$errmsg == ""} { set errmsg $res }
+            # Since we don't pop up an error dialog, let's at least try to show
+            # what happened in the viewer window, if there is one
+            if {$viewer != ""} {
+               $v_w.text insert end "$res\n" stderr
+               if {[tell $procerr]} {
+                 seek $procerr 0
+                 while {[gets $procerr erline] != -1} {
+                   $v_w.text insert end "$erline\n" stderr
+                 }
+               }
+             }
           } else {
             gen_log:log D "  Close OK"
             set ExecDone [list 0]
@@ -116,30 +131,31 @@ namespace eval ::exec {
         variable procerr
         variable errmsg
         variable viewer
+        variable filter
+        variable show_stderr
         variable v_w
 
         #SRIV this is the key to no cpu usage!
-        #fileevent $procerr readable {}
+        fileevent $procerr readable {}
 
         # When new stuff appears in the error output file, get it.  There may
         # be more than one line.
+        set errmsg ""
         if {[tell $procerr] != $errpos} {
           seek $procerr $errpos start
           while {[gets $procerr erline] != -1} {
-            append errmsg "$erline\n"
+            append errmsg "$erline"
             set errpos [tell $procerr]
           }
-          # FIXME Usually it's good to see stderr, especially for checkout.
-          # But sometimes you don't want to.  Either better filters or
-          # it could be an option or an argument
           gen_log:log E "$errmsg"
-          if {$viewer != ""} {
+          if {$viewer != "" && $show_stderr == 1} {
             $v_w.text insert end "$errmsg\n" stderr
           }
         }
         
         #SRIV this is the key to no cpu usage!
         #after 1 [list catch {fileevent $procerr readable [namespace current]::err_handler}]
+        catch {fileevent $procerr readable [namespace current]::err_handler}
       }
 
       proc abort {} {
@@ -300,18 +316,18 @@ namespace eval ::viewer {
 
       viewer_window $w $title [namespace current]
 
-      proc do { command {filter {}} } {
+      proc do { command {show_stderr {1}} {filter {}} } {
         global cvscfg
         variable w
         variable v_e
 
-        gen_log:log T "ENTER (\"$command\" \"$filter\")"
+        gen_log:log T "ENTER (\"$command\" \"$show_stderr\" \"$filter\")"
 
         pack forget $w.close
         pack $w.stop -in $w.bottom -side right -ipadx 15
 
         # Send the command to the execution module
-        set v_e [::exec::new $command [namespace current] $filter]
+        set v_e [::exec::new $command [namespace current] $show_stderr $filter]
 
         gen_log:log T "LEAVE"
       }
@@ -390,7 +406,6 @@ proc patch_colortags {exec line} {
 
   gen_log:log T "ENTER ($exec \"$line\")"
 
-  set tag default
   # Return the type of the line being output
   if {[regexp { is new; } $line]} {
       set tag added
@@ -456,9 +471,12 @@ namespace eval ::view_output {
 
 proc viewer_window {w title parent} {
   global cvscfg
+  global tcl_platform
 
   toplevel $w
-  wm iconbitmap $w @$cvscfg(bitmapdir)/cvs-says.xbm
+  if {$tcl_platform(platform) != "windows"} {
+    wm iconbitmap $w @$cvscfg(bitmapdir)/cvs-says.xbm
+  }
   wm protocol $w WM_DELETE_WINDOW "$w.close invoke"
 
   text $w.text -setgrid yes -relief sunken -border 2 \
