@@ -3,7 +3,7 @@
 #
 
 #
-# $Id: help.tcl,v 1.51 2004/01/02 01:38:32 dorothyr Exp $
+# $Id: help.tcl,v 1.55 2004/04/25 06:00:24 dorothyr Exp $
 #
 # Help procedures and help data.
 #
@@ -32,7 +32,7 @@ proc aboutbox {} {
   frame .about.top
 
   message .about.top.msg1 -width 400 -justify c \
-    -text "\nTkCVS Version 7.2\n" -font $cvscfg(guifont)
+    -text "\nTkCVS Version 7.2.1\n" -font $cvscfg(guifont)
   pack .about.top -side top -expand 1 -fill both
 
   image create photo Tclfish -format gif -file \
@@ -186,6 +186,7 @@ proc purge-all-tags {w start end} {
 
 proc do_help {title helptext} {
   global cvscfg
+  global tcl_platform
 
   gen_log:log T "ENTER $title <helptext suppressed>)"
   static {helpviewer 0}
@@ -206,7 +207,9 @@ proc do_help {title helptext} {
   pack $cvshelpview.text -fill both -expand 1
 
   wm title $cvshelpview "$title Help"
-  wm iconbitmap $cvshelpview @$cvscfg(bitmapdir)/tkcvs-help.xbm
+  if {$tcl_platform(platform) != "windows"} {
+    wm iconbitmap $cvshelpview @$cvscfg(bitmapdir)/tkcvs-help.xbm
+  }
   wm minsize $cvshelpview 1 1
 
   put-text $cvshelpview.text $helptext
@@ -220,7 +223,7 @@ proc man_description {} {
 
 <h1>DESCRIPTION</h1>
 
-TkCVS is a Tcl/Tk-based graphical interface to the CVS configuration management system. It displays the status of the files in the current working directory, and provides buttons and menus to execute CVS commands on the selected files. TkDiffB is included for browsing and merging your changes.
+TkCVS is a Tcl/Tk-based graphical interface to the CVS configuration management system. It displays the status of the files in the current working directory, and provides buttons and menus to execute CVS commands on the selected files. TkDiff is included for browsing and merging your changes.
 
 TkCVS extends CVS with a method to produce a browsable, "user friendly" listing of modules in the repository. This requires some manual editing of the CVSROOT/modules file the first time - see the online help.
   }
@@ -334,7 +337,7 @@ The file is a directory.
 
 <h2>Editors Display</h2>
 
-If the option cvscfg(econtrol) has been set then an extra column will appear in the current directory display labelled "editors". This gives the edit status of each of the files in the current directory so it can be easily seen who is currently editing the file. Refer to the CVS documentation for details of how to set up the repository for using the "cvs edit" feature using "cvs watch on", etc.
+If the option cvscfg(econtrol) has been set then an extra column will appear in the current directory display labeled "editors". This gives the edit status of each of the files in the current directory so it can be easily seen who is currently editing the file. Refer to the CVS documentation for details of how to set up the repository for using the "cvs edit" feature using "cvs watch on", etc.
 
 <h2>File Filters</h2>
 
@@ -381,10 +384,10 @@ This button will bring up the log browser window for each of the selected files
 Chooses a "representative" file in the current directory and diagrams only the branch tags. Useful for batch merging.
 
 <itl>Diff:</itl>
-This compares the selected files with the equivalent files in the repository. A separate program called "TkDiffB" (also supplied with TkCVS) is used to do this. For more information on TkDiffB, see TkDiffB's help menu.
+This compares the selected files with the equivalent files in the repository. A separate program called "TkDiff" (also supplied with TkCVS) is used to do this. For more information on TkDiff, see TkDiff's help menu.
 
 <itl>Merge Conflict:</itl>
-If a file's status says "Needs Merge", "Conflict", or is marked with a "C" in CVS Check, there was a difference which CVS needs help to reconcile. This button invokes TkDiffB with the -conflict option, opening a merge window to help you merge the differences.
+If a file's status says "Needs Merge", "Conflict", or is marked with a "C" in CVS Check, there was a difference which CVS needs help to reconcile. This button invokes TkDiff with the -conflict option, opening a merge window to help you merge the differences.
 
 <itl>Update:</itl>
 This updates your sandbox directory with any changes committed to the repository by other developers.
@@ -572,7 +575,7 @@ Before importing a new module, first check to make sure that you have write perm
 
 To import a module you first need a directory where the module is located. Make sure that there is nothing in this directory except the files that you want to import.
 
-Press the big "Module Browser" button in the top part of the tkcvs UI, or use CVS -> Import WD into Repository from the menubar.
+Press the big "Module Browser" button in the top part of the tkcvs UI, or use CVS -> Import WD into Repository from the menu bar.
 
 In the module browser, press the Import button on the bottom, the one that shows a folder and an up arrow.
 
@@ -600,6 +603,85 @@ The current version number of the module. This should be a number of the form X.
   }
 }
 
+proc importing_to_existing_module {} {
+
+  do_help "Importing To An Existing Module" {
+
+<h1>IMPORTING TO AN EXISTING MODULE</h1>
+
+Before importing to an existing module, first check to make sure that you have write permission to the repository.
+
+To import to an existing module you first need a directory where the code is located. Make sure that there is\
+nothing in this directory (including no CVS directory) except the files that you want to import.
+
+Open up the Module Browser by selecting File/Browse Modules from the menu bar.
+
+In the Module Browser, select File/Import To An Existing Module from the menu bar.
+
+In the dialog that pops up, press the Browse button and select the name of an existing module. Press the OK to\
+close this dialog box. Enter the version number of the code to be imported. 
+
+OK the dialog.  Several things happen now.  The directory is imported, your original directory is saved as\
+directory.orig, and the newly created module is checked out.
+
+When it finishes, you will find the original Working Directory Browser showing the original code. If you\
+press the "Re-read the current directory" button you will see the results of the checked out code.
+
+Here is a more detailed description of the fields in the Import Dialog.
+
+<itl>Module Name:</itl>
+A name for the existing module. Filled in by the use of the the Browse button
+
+<itl>Module Path:</itl>
+The location in the repository tree where the existing module is. Filled in by the use of the Browse button. 
+
+<itl>Version Number:</itl>
+The current version number of the module to be imported. This should be a number of the form X.Y.Z where\
+.Y and .Z are optional. You can leave this blank, in which case 1 will be used as the first version number.
+  }
+}
+
+proc vendor_merge {} {
+
+  do_help "Vendor Merge" {
+
+<h1>VENDOR MERGE</h1>
+
+Software development is sometimes based on source distribution from a vendor or third-party distributor.\
+After building a local version of this distribution, merging or tracking the vendor's future release into\
+the local version of the distribution can be done with the vendor merge command.
+
+The vendor merge command assumes that a separate module has already been defined for the vendor or third-party\
+distribution with the use of the "Import To A New Module" and "Import To An Existing Module" commands. It also\
+assumes that a separate module has already been defined for the local code for which the vendor merge operation\
+is to be applied to.
+
+Start from an empty directory and invoke tkcvs. Open up the Module Browser by selecting File/Browse Modules from the menu bar.
+
+Checkout the module of the local code to be merged with changes from the vendor module. (Use the red icon with the\
+down arrow)
+
+In the Module Browser, after verifying that the Module entry box still has the name the module of the local code to which\
+the vendor code is to be merged into, select File/Vendor Merge from the menu bar.
+
+In the Module Level Merge With Vendor Code window, press the Browse button to select the module to be used as the vendor module.
+
+OK the dialog. All revisions from the vendor module will be shown in the two scroll lists. Fill in the From and To entry\
+boxes by clicking in the appropriate scroll lists.
+
+Ok the dialog. Several things happens now. Several screens will appear showing the output from cvs commands for\
+(1)checking out temp files, (2)cvs merge, and (3)cvs rdiff. Information in these screens will tell you what routines will have\
+merge conflicts and what files are new or deleted. After perusing the files, close each screen. <itl>(In the preceeding\
+dialog box, there was an option to save outputs from the merge and rdiff operations to files CVSmerge.out and CVSrdiff.out.)</itl>
+
+The checked out local code will now contain changes from a merge between two revisions of the vendor modules. This\
+code will not be checked into the repository. You can do that after you've reconciled conflicts and decide if that is what you\
+really want. 
+
+A detailed example on how to use the vendor merge operation is provided in the PDF file vendor5readme.pdf. 
+  }
+}
+
 proc configuration_files {} {
 
   do_help "Configuration Files" {
@@ -641,7 +723,7 @@ Most colors and fonts can be customized by using the options database. For examp
 <h3>cvscfg(colourA) cvscfg(colourB)</h3>
 Hilight colours for revision-log boxes
 <h3>cvscfg(tagdepth)</h3>
-Number of tags you want to see for each revision on the branching diagram before it says "more..." and offers a popup to show the rest
+Number of tags you want to see for each revision on the branching diagram before it says "more..." and offers a pop-up to show the rest
 <h3>cvscfg(tagcolour,tagstring)</h3>
 Colors for marking tags. For example:
 <cmp>    set cvscfg(tagcolour,tkcvs_r6) Purple</cmp>
@@ -654,7 +736,7 @@ In the module browser, if true this will cause the alias modules to be grouped i
 <h3>cvscfg(allfiles)</h3>
 Set this to false to see normal files only in the directory browser. Set it to true to see all files including hidden files.
 <h3>cvscfg(auto_status)</h3>
-Set the default for automatic statusing of a CVS controlled directory. Automatic updates are done when a directory is entered and after some operations.
+Set the default for automatic status-refresh of a CVS controlled directory. Automatic updates are done when a directory is entered and after some operations.
 <h3>cvscfg(auto_tag)</h3>
 Whether to tag the merged-from revision when using TkCVS to merge different revisions of files by default.  A dialog still lets you change your mind, regardless of the default.
 <h3>cvscfg(checkrecursive)</h3>
@@ -683,6 +765,8 @@ for both.  CVS rule: a tag must not contain the characters `$,.:;@'
 Detail for repository and workdir reports (terse, summary, verbose)
 <h3>cvscfg(recurse)</h3>
 Whether reports are recursive (true or false)
+<h3>cvscfg(savelines)</h3>
+How many lines to keep in the trace window
 <h3>cvscfg(status_filter)</h3>
 Filter out unknown files (status "?") from CVS Check and CVS Update reports.
 <h3>cvscfg(use_cvseditor)</h3>
@@ -692,7 +776,7 @@ Let CVS invoke an editor for commit log messages rather than having tkcvs use it
 <h3>cvscfg(file_filter)</h3>
 Pattern for which files to list. Empty string is equivalent to the entire directory (minus hidden files)
 <h3>cvscfg(ignore_file_filter)</h3>
-Pattern used in the workdir listbox filter for files to be ignored
+Pattern used in the workdir filter for files to be ignored
 <h3>cvscfg(clean_these)</h3>
 Pattern to be used for cleaning a directory (removing unwanted files)
 
