@@ -22,6 +22,7 @@ namespace eval joincanvas {
 
       global cvscfg
       global cvs
+      global tcl_platform
 
       # Height and width to draw boxes
       variable cvscanv
@@ -490,7 +491,9 @@ namespace eval joincanvas {
       }
 
       toplevel $joincanvas
-      wm iconbitmap $joincanvas @$cvscfg(bitmapdir)/dirbranch.xbm
+      if {$tcl_platform(platform) != "windows"} {
+        wm iconbitmap $joincanvas @$cvscfg(bitmapdir)/dirbranch.xbm
+      }
       wm protocol $joincanvas WM_DELETE_WINDOW \
         [namespace code {$joincanvas.close invoke}]
 
