@@ -3,7 +3,7 @@
 #
 
 #
-# $Id: logcanvas.tcl,v 1.68 2004/01/02 04:24:44 dorothyr Exp $
+# $Id: logcanvas.tcl,v 1.70 2004/03/12 07:37:05 dorothyr Exp $
 #
 # Contains procedures used for the log canvas for tkCVS.
 #
@@ -46,6 +46,7 @@ namespace eval ::logcanvas {
       set my_idx [uplevel {concat $my_idx}]
       global cvscfg
       global cvs
+      global tcl_platform
       variable directory [uplevel {concat $directory}]
       variable filename [uplevel {concat $filename}]
       variable localfile [uplevel {concat $localfile}]
@@ -110,7 +111,7 @@ namespace eval ::logcanvas {
         busy_start $logcanvas
         set tags(1) {}
         set logstate {R}
-        set cmd_log [::exec::new $command {} [namespace current]::ParseLog]
+        set cmd_log [::exec::new $command {} 0 [namespace current]::ParseLog]
         # wait for it to finish so our arrays are all populated
         $cmd_log\::wait
         if {[catch {cd $cwd}]} {
@@ -1464,7 +1465,9 @@ namespace eval ::logcanvas {
           SaveOptions
         }]
       menu_std_help $logcanvas.menubar
-      wm iconbitmap $logcanvas @$cvscfg(bitmapdir)/branch.xbm
+      if {$tcl_platform(platform) != "windows"} {
+        wm iconbitmap $logcanvas @$cvscfg(bitmapdir)/branch.xbm
+      }
       wm protocol $logcanvas WM_DELETE_WINDOW \
         [namespace code {$logcanvas.close invoke}]
       frame $logcanvas.up -relief groove -border 2
