@@ -2,11 +2,18 @@
 # TCL Library for TkCVS
 
 #
-# $Id: merge.tcl,v 1.17 2003/10/13 07:13:29 dorothyr Exp $
+# $Id: merge.tcl,v 1.18 2004/03/08 05:44:37 dorothyr Exp $
 #
+# Modifications by Eugene Lee 10/16/03 
+# 1. .merge window made more robust so user cannot key in incorrect data.
+# 2. Name of Vendor Module is selectable by user (no longer hardcoded to Vendor). 
+#    proc vendor_wait no longer used
+# 3. Added proc vendorDialog
+ 
 
 proc merge_run {mcode} {
 # By: Eugene Lee, Aerospace Corporation, 11/12/95
+# Modified by E. Lee 10/16/03
   global cvs
   global modbrowse_module
   global from_to
@@ -14,7 +21,6 @@ proc merge_run {mcode} {
   global cwd
   global module_dir
   global merge
-
   gen_log:log T "ENTER ($mcode)"
 
   if {$mcode == ""} {
@@ -24,8 +30,8 @@ proc merge_run {mcode} {
   }
 
   if {[winfo exists .merge]} {
-    .merge.right.tcwd configure -text cwd
-    .merge.right.tmodule configure -text module_dir
+    .merge.right.tcwd configure -textvariable cwd
+    .merge.right.tmodule configure -textvariable modbrowse_module
     wm deiconify .merge
     raise .merge
     grab set .merge
@@ -48,11 +54,10 @@ proc merge_run {mcode} {
   pack .merge.left   -side left
   pack .merge.right  -side right -fill x -expand yes
 
-  label .merge.left.lcwd      -text "Current Directory"   -anchor w
-  label .merge.left.lmodule   -text "Module Location"    -anchor w
-
-  entry .merge.right.tcwd     -relief sunken -width 40 -text $cwd
-  entry .merge.right.tmodule  -width 40 -text $module_dir
+  label .merge.left.lcwd      -text "Current Directory" -width 16  -anchor w
+  label .merge.left.lmodule   -text "Module"  -width 16  -anchor w
+  label .merge.right.tcwd  -textvariable cwd   -relief sunken -width 40 -anchor w
+  label .merge.right.tmodule -textvariable modbrowse_module -relief sunken -width 40 -anchor w
 
   pack .merge.left.lcwd       -side top   -fill x -pady 3
   pack .merge.left.lmodule    -side top   -fill x
@@ -61,18 +66,15 @@ proc merge_run {mcode} {
 
   frame .merge.vendor.name
   pack .merge.vendor.name -side top -fill x -expand yes
-  label .merge.vendor.name.l -text "Vendor Module" -anchor w
-  entry .merge.vendor.name.e -relief sunken -textvariable venselect_mcode
+  label .merge.vendor.name.l -text "Vendor Module" -width 16 -anchor w
+  label .merge.vendor.name.e -relief sunken -textvariable venselect_mcode -anchor w
+  button .merge.vendor.name.b -text "Browse ..." -command "vendorDialog"
   pack .merge.vendor.name.l -side left -fill x -pady 3
+  pack .merge.vendor.name.b -side right -anchor w -fill x 
   pack .merge.vendor.name.e -side right -anchor w -fill x -pady 3 -expand yes
   #.merge.vendor.name.e config -state disabled
   bind .merge.vendor.name.e <Return> { put_rev_tags $venselect_mcode }
 
-  button .merge.vendor.b -text \
-    "Select Module With Vendor Code From Repository" -anchor w \
-    -command vendor_wait
-  pack .merge.vendor.b -side top -ipadx 2 -ipady 2  \
-    -padx 4 -pady 4
   frame .merge.vendor.l
   frame .merge.vendor.r
   pack .merge.vendor.l .merge.vendor.r -side left
@@ -90,7 +92,7 @@ proc merge_run {mcode} {
       eval {listbox .merge.vendor.$i.scroll.list \
               -yscrollcommand [list .merge.vendor.$i.scroll.sy set] \
               -xscrollcommand [list .merge.vendor.$i.scroll.sx set]} \
-      -relief sunken -width 40 -height 15
+      -relief sunken -width 40 -height 8
     scrollbar .merge.vendor.$i.scroll.sx -orient horizontal \
       -command [list .merge.vendor.$i.scroll.list xview] \
       -relief sunken
@@ -119,17 +121,31 @@ proc merge_run {mcode} {
 
   button .merge.ok -text "OK" \
     -command {
+      if { $venselect_mcode == "" } {
+         cvsfail "Please select a Vendor"
+         return
+      }
+      catch do_merge results
+      if { $results == "err" } { return }
       grab release .merge
       wm withdraw .merge
-      do_merge
     }
-  button .merge.quit -text "Close" \
+  button .merge.quit -text "Cancel" \
     -command {
       grab release .merge
       wm withdraw .merge
     }
+  radiobutton .merge.saveno -variable saveMergeOutput -text no \
+     -value 0
+  radiobutton .merge.saveyes -variable saveMergeOutput -text yes \
+     -value 1
+  label .merge.savemergeoutput -text \
+     "   Save CVS merge and rdiff outputs to CVSmerge.out & CVSrdiff.out?"
   pack .merge.ok .merge.quit -in .merge.down -side left \
-    -ipadx 2 -ipady 2 -padx 4 -pady 4 -fill both -expand 1
+    -ipadx 2 -ipady 2 -padx 4 -pady 4 -fill both 
+  pack .merge.savemergeoutput .merge.saveno .merge.saveyes \
+    -in .merge.down -side left 
+  .merge.saveno select; # preset to no
 
   bind .merge.vendor.l.scroll.list <<ListboxSelect>> {
     get_j .merge.vendor.l.scroll.list left
@@ -166,7 +182,7 @@ proc get_j { list side} {
 
 proc put_rev_tags {code} {
 # Written by Eugene A. Lee, Aerospace Corp., 11/12/95
-#Called by button .venselect.ok in venget.tcl
+# Called by button .venselect.ok in venget.tcl
 # Made usable for remote repositories by MK
 #
 # Go to the tmpdir aka cvs.tcl
@@ -239,44 +255,103 @@ proc do_merge {} {
   global cvscfg
   global cvs
   global venselect_mcode
-
+  global saveMergeOutput
+  global modbrowse_module
+  
   gen_log:log T "ENTER"
   set merge(3rd_party) $venselect_mcode
   if { $merge(3rd_party) == "" } {
-    puts "Vendor Module not specified"
-    return
+    cvsfail "Vendor Module not specified"
+    return err
   }
 
   if { $merge(from) == "" || $merge(to) == "" } {
-    puts "not all entries filled"
-    return
+    cvsfail "not all entries filled"
+    return err
   }
-
-  set merge(mod_dir) [pwd]
-
+  
+  # In order to merge difference between tags of 3rd_party into $modbrowse_module
+  # the directory where the merge is to be done later must be in the checkout 
+  # directory of $modbrowse_module. If the user just checked out the 
+  # $modbrowse_module and invoked the merge command, the current directory at this
+  # point in the script is most likely one above directory $modbrowse_module. 
+  # Check for this and save the directory where the merge operation is to be done
+  # later.
+  if { [file tail [pwd]] == $modbrowse_module } {
+     set dir4merge [pwd]
+  } else {
+     set tmpdir [glob -nocomplain $modbrowse_module]
+     if { $tmpdir == "" } {
+        cvsfail "You must invoke the merge command from the checked out 
+directory of $modbrowse_module or one above it"
+        return
+     }
+     set dir4merge [file join [pwd] $tmpdir]
+  }
+  
   set mess "This will merge differences between $merge(from) and"
-  append mess " $merge(to) of $merge(3rd_party) into $merge(mod_dir)"
+  append mess " $merge(to) of $merge(3rd_party) into $modbrowse_module"
   append mess "\n\n Are you sure?"
   if {[cvsconfirm $mess] == 0} {
+    # The CVS directory in the checked out $modbrowse_module are associated with
+    # $modbrowse_module. Since we are going to merge in differences between 
+    # $merge(from) & $merge(to) of $merge(3rd_party), the CVS directory to be used
+    # later in directory $dir4merge needs to from directory $merge(3rd_party).
+    # Do that next and save it into a temp directory mktemp_dir
+  
     set mktemp "$cvscfg(tmpdir)/merge[pid]"
     set mktemp_dir $mktemp.dir
     set cmd "$cvs checkout -d $mktemp_dir -r$merge(from) $merge(3rd_party)"
     catch {eval "exec $cmd"} view_this
+    
     view_output::new "CVS Checkout of temp file for $merge(3rd_party)" $view_this
     gen_log:log F "[pwd]"
-    file delete -force CVS_save
-    file rename CVS CVS_save
-    file copy -force [file join $mktemp_dir CVS] .
-    file delete -force $mktemp_dir
 
-    set cmd "$cvs checkout -d $merge(mod_dir) -j$merge(from) -j$merge(to) $merge(3rd_party)"
+    # CVS directory in $mktemp_dir will be copied later
+    
+    cd $dir4merge
+    # Save CVS directory of $modbrowse_module which is to be restored after\
+    # the merge command has been completed. Save it to $mktemp_dir
+    file copy CVS [file join $mktemp_dir CVS_save]
+    file delete -force CVS; # Need -force for a directory
+    # Then copy the CVS file from $mktemp_dir
+    file copy -force [file join $mktemp_dir CVS] CVS
+   
+    set cmd "$cvs checkout -d [pwd] -j$merge(from) -j$merge(to) $merge(3rd_party)"
     catch {eval "exec $cmd"} view_this
+    if { $saveMergeOutput == 1 } {
+       set tmpfile "CVSmerge.out"
+       file delete -force $tmpfile
+       set fileId [open $tmpfile w]
+       foreach line [split $view_this \n\r"] {
+	 puts $fileId $line
+       }
+       close $fileId
+    }
+
     view_output::new \
-       "CVS Module Level Merge of $merge(3rd_party) into $merge(mod_dir)" \
+       "CVS Module Level Merge of $merge(3rd_party) into $modbrowse_module" \
        $view_this
 
+    set cmd "$cvs rdiff -s -r$merge(from) -r$merge(to) $merge(3rd_party)"
+    catch {eval "exec $cmd"} view_this
+    if { $saveMergeOutput == 1 } {
+       set tmpfile "CVSrdiff.out"
+       file delete -force $tmpfile
+       set fileId [open $tmpfile w]
+       foreach line [split $view_this \n\r"] {
+	 puts $fileId $line
+       }
+       close $fileId
+    }
+    view_output::new \
+       "CVS rdiff from $merge(from) to $merge(to) for $merge(3rd_party)" \
+       $view_this
+       
     file delete -force CVS
-    file rename CVS_save CVS
+    file delete -force $mktemp_dir
+    # Restore CVS directory associated with #modbrowse_module
+    file copy [file join $mktemp_dir CVS_save] CVS
   }
   gen_log:log T "LEAVE"
 }
@@ -419,20 +494,53 @@ proc merge_taglist {files} {
   return $keepers
 }
 
-proc vendor_wait { } {
-  global modbrowse_module
-  global venselect_mcode
+proc vendorDialog {    } {
+   global ExModList ExModDirList
+   global venselect_mcode
+   set w .venDialog
+   grab release .merge
+   catch {destroy $w}
+   toplevel $w
+   wm title $w "Select A Vendor"
+   grab set $w
 
-  gen_log:log T "ENTER"
+frame $w.buttons
+pack $w.buttons -side bottom -fill x -pady 2m
+button $w.buttons.ok -text Ok -command {
+  if {$venselect_mcode == ""} {
+     return
+  }
+   put_rev_tags $venselect_mcode
+   destroy .venDialog
+   raise .merge
+   grab set .merge
+   }
+button $w.buttons.cancel -text Cancel \
+   -command {
+     grab release .venDialog
+     wm withdraw .venDialog
+   }
 
-  raise .modbrowse
-  set local_mcode $modbrowse_module
-  gen_log:log D "local $local_mcode"
-  tkwait variable modbrowse_module
-  set venselect_mcode $modbrowse_module
-  gen_log:log D "vendor $venselect_mcode"
+pack $w.buttons.ok -side left -expand 1
+pack $w.buttons.cancel -side left -expand 1
 
-  put_rev_tags $venselect_mcode
-  raise .merge
-  gen_log:log T "LEAVE"
+frame $w.frame -borderwidth .5c
+pack $w.frame -side top -expand yes -fill y
+
+scrollbar $w.frame.scroll -command "$w.frame.list yview"
+listbox $w.frame.list -yscroll "$w.frame.scroll set" -setgrid 1 -height 5
+pack $w.frame.scroll -side right -fill y
+pack $w.frame.list -side left -expand 1 -fill both
+
+   getExistModDialog 
+   set nModule [llength $ExModList]
+   for {set i 0} {$i < $nModule} {incr i} {
+     $w.frame.list insert end [lindex $ExModList $i]
+   }
+
+bind $w.frame.list <Button-1> {
+  set venselect_mcode [%W get [%W nearest %y] ]
 }
+
+
+}   
