@@ -1,5 +1,5 @@
 #
-# $Id: tkcvs_def.tcl,v 1.47 2004/01/02 06:40:26 dorothyr Exp $
+# $Id: tkcvs_def.tcl,v 1.54 2004/04/26 07:00:38 dorothyr Exp $
 #
 # TkCVS defaults file.
 #
@@ -144,37 +144,6 @@ set logcfg(show_box_revtime) 0
 set logcfg(show_box_revlines) 0
 set logcfg(show_box_revstate) 0
 
-
-
-# --------------------
-# Import defaults
-set cvscfg(import_vendortag) {VENDOR}
-set cvscfg(import_vendorbranch) {1.1.1}
-# Standalone CVS import behaviour
-#set cvscfg(import_newtrunk) 2
-#set cvscfg(import_missdel) 0
-# Recommended settings
-set cvscfg(import_newtrunk) 0
-set cvscfg(import_missdel) 1
-set cvscfg(import_alttime) {}
-# It is *highly* recommended that you configure cvswrappers to set -kb for
-# binary file types and -ko for all others, then change the default kflag
-# below to {} rather than {-ko}.
-set cvscfg(import_kflag) {-ko}
-# You should clean your import directory by hand unless you are absolutely
-# *certain* you know what ignore patterns are in effect - otherwise you may
-# lose files that never get imported!
-set cvscfg(import_ignore) {!}
-
-# If you have standard files that you want present in a module when it is
-# created by import without a directory specified (e.g. README, COPYRIGHT
-# etc.) then you can put them in a directory and set cvscfg(module_template)
-# to its name. Note that importing to an existing module without a directory
-# specified will also add the template files to both the vendor branch and
-# the trunk.
-#set cvscfg(module_template) {}
-
-
 # --------------------
 # Platform specific configuration.
 #
@@ -199,7 +168,7 @@ if {$tcl_platform(platform) == "windows"} {
 
     # set temp directory
     set cvscfg(tmpdir) "c:/temp"
-    set cvscfg(tkdiff) "$TclExe [file join $ScriptBin tkdiff.tcl]"
+    set cvscfg(tkdiff) "$TclExe [file join \"[file dirname $ScriptBin] tkdiff.tcl\"]"
     set cvscfg(print_cmd)          "pr"
     set cvscfg(shell)  ""
     #
@@ -251,10 +220,18 @@ if {$tcl_platform(platform) == "windows"} {
     set cvscfg(allow_abort)    "yes"
     # What do you want to happen when you ask for a shell?
     set cvscfg(shell) "xterm -name tkcvsxterm -n {TkCVS xterm}"
+
+    # Some special stuff for MacOSX "native" Tk
     if {! [catch {set windowingsystem [tk windowingsystem]}] && $windowingsystem == "aqua"} {
-      set cvscfg(editor) /Applications/TextEdit.app/Contents/MacOS/textedit
-      set cvscfg(tkdiff) "\"$ScriptBin/../../MacOS/Wish Shell\" $ScriptBin/tkdiff.tcl"
+      set cvscfg(editor) /Applications/TextEdit.app/Contents/MacOS/TextEdit
       set cvscfg(shell) /Applications/Utilities/Terminal.app/Contents/MacOS/Terminal
+      set cvscfg(tkdiff) "\"/Applications/TkDiff.app/Contents/MacOS/Wish Shell\""
+
+      # We can't do the Aqua "pinstripes", but at least this helps keep
+      # the UI from being completely washed out (thanks Bryan Oakley)
+      option add *background #ebebeb
+      option add *Canvas.background #f0f0f0
+      option add *Entry.background #ffffff
     }
 }
 
@@ -325,6 +302,8 @@ set cvscfg(status_filter)      false
 set cvscfg(log_classes) "CEF"
 # On (1) or off (0)
 set cvscfg(logging)    false
+# How many trace lines to save.  The debugging output can get very large.
+set cvscfg(trace_savelines) 5000
 
 # In the Module Browser, if true this will cause the alias modules to
 # be grouped in one folder.  Cleans up clutter if there are a lot of
@@ -347,7 +326,7 @@ set cvscfg(outputColor,added)   darkgreen
 set cvscfg(outputColor,removed) maroon
 set cvscfg(outputColor,warning) orange
 set cvscfg(outputColor,unknown) gray30
-set cvscfg(outputColor,stderr) darkred
+set cvscfg(outputColor,stderr) red4
 
 # Print setup. Removed in v7.1
 #set cvscfg(papersize) "A4"
