@@ -3,7 +3,7 @@
 #
 
 #
-# $Id: workdir.tcl,v 1.136 2003/12/21 07:46:29 dorothyr Exp $
+# $Id: workdir.tcl,v 1.140 2004/03/14 03:44:08 dorothyr Exp $
 #
 # Current working directory display.  Handles all of the functions
 # concerned with navigating about the current directory on the main
@@ -17,6 +17,7 @@ proc workdir_setup {} {
   global cvsglb
   global current_tagname
   global logclass
+  global tcl_platform
 
   gen_log:log T "ENTER"
   set cwd [pwd]
@@ -33,7 +34,9 @@ proc workdir_setup {} {
   toplevel .workdir
   wm title .workdir "TkCVS Working Directory"
   wm iconname .workdir "TkCVS"
-  wm iconbitmap .workdir @$cvscfg(bitmapdir)/tkcvs48.xbm
+  if {$tcl_platform(platform) != "windows"} {
+    wm iconbitmap .workdir @$cvscfg(bitmapdir)/tkcvs48.xbm
+  }
   wm minsize .workdir 430 300
   wm protocol .workdir WM_DELETE_WINDOW { .workdir.close invoke }
   wm withdraw .
@@ -597,6 +600,10 @@ proc menu_std_help { w } {
      -command module_browser
   $w.help add command -label "Importing New Modules" \
      -command importing_new_modules
+  $w.help add command -label "Importing To An Existing Module" \
+     -command importing_to_existing_module
+  $w.help add command -label "Vendor Merge" \
+     -command vendor_merge
   $w.help add separator
   $w.help add command -label "Configuration Files" \
      -command configuration_files
@@ -639,7 +646,7 @@ proc workdir_edit_command {file} {
       }
     }
   }
-  return "$cvscfg(editor) $cvscfg(editorargs) \"$file\""
+  return "\"$cvscfg(editor)\" $cvscfg(editorargs) \"$file\""
 }
 
 proc workdir_newdir {file} {
@@ -829,7 +836,7 @@ proc setup_dir { } {
   }
 
   cd $cwd
-  #gen_log:log F "CD [pwd]"
+  gen_log:log F "CD [pwd]"
 
   set module_dir ""
   set current_tagname ""
